----------------------------------------------------------------------------------------
---Adapted from:
-- Name: BOS-100 - Stennis Hornet and Tomcat
-- Author: funkyfranky
-- Date Created: 17 August 2019
--
-- # Situation:
-- 
-- Practice Case I/II/III recovery using the F/A-18C Hornet or F-14B Tomcat.
-- 
-- See mission briefing for further details.
-- 
-- *** IMPORTANT ***
-- If you run the mission in single player, hit ESC twice before entering a slot!
-- Otherwise the script will not load due to a long standing DCS bug.
--
-- Carrier group ships: 
-- Lincoln CVN 72
-- Rentz (Huey Radio Relay based here) - Perry class, 
-- Mike Murphy (Rescue Helo based here),  John Paul Jones - Arleigh Burke class 
-- Chosin, Vella Gulf, Anzio - Ticonderoga class 
--
----------------------------------------------------------------------------------------

-- No MOOSE settings menu. Comment out this line if required.
_SETTINGS:SetPlayerMenuOff()

-- CAP1 spawning in air. Orbit fixed on starboard perimeter ship
local tanker=RECOVERYTANKER:New("John Paul Jones", "CAP 3 Group")
tanker:SetTakeoffAir()
tanker:SetHomeBase(AIRBASE:FindByName("Lincoln"))
tanker:SetRadio(305)
tanker:SetModex(011)
tanker:SetAltitude(26000)
tanker:__Start(1)

-- S-3B Recovery Tanker spawning in air.
local tanker=RECOVERYTANKER:New("Lincoln", "Texaco Group")
tanker:SetTakeoffAir()
tanker:SetRadio(250)
tanker:SetModex(511)
tanker:SetTACAN(1, "TEX")
tanker:__Start(1)

-- E-2D AWACS spawning in air.
local awacs=RECOVERYTANKER:New("Lincoln", "E-2D Wizard Group")
awacs:SetTakeoffAir()
awacs:SetAWACS()
awacs:SetRadio(260)
awacs:SetAltitude(20000)
awacs:SetCallsign(CALLSIGN.AWACS.Wizard)
awacs:SetRacetrackDistances(30, 1)
awacs:SetModex(611)
awacs:SetTACAN(2, "WIZ")
awacs:__Start(1)

-- Rescue Helo with home base Mike Murphy. Has to be a global object!
rescuehelo=RESCUEHELO:New("Lincoln", "Rescue Helo")
rescuehelo:SetHomeBase(AIRBASE:FindByName("Mike Murphy"))
rescuehelo:SetModex(42)
rescuehelo:__Start(1)
  
-- Create AIRBOSS object.
local AirbossAbe=AIRBOSS:New("Lincoln")

-- Add recovery windows:
-- Case I from 8 to 9 am.
local window1=AirbossAbe:AddRecoveryWindow( "8:00", "9:00", 1, nil, true, 25)
-- Case II with +15 degrees holding offset from 15:00 for 60 min.
local window2=AirbossAbe:AddRecoveryWindow("15:00", "16:00", 2,  nil, true, 23)
-- Case III with +30 degrees holding offset from 2100 to 2200.
local window3=AirbossAbe:AddRecoveryWindow("21:00", "22:00", 3,  nil, true, 21)

-- Set folder of airboss sound files within miz file.
AirbossAbe:SetSoundfilesFolder("Airboss Soundfiles/")

-- Single carrier menu optimization.
AirbossAbe:SetMenuSingleCarrier()

-- Skipper menu.
AirbossAbe:SetMenuRecovery(30, 20, false)

-- Remove landed AI planes from flight deck.
AirbossAbe:SetDespawnOnEngineShutdown()

-- Load all saved player grades from your "Saved Games\DCS" folder (if lfs was desanitized).
AirbossAbe:Load()

-- Automatically save player results to your "Saved Games\DCS" folder each time a player get a final grade from the LSO.
AirbossAbe:SetAutoSave()

-- Enable trap sheet.
AirbossAbe:SetTrapSheet()

-- Set TACAN ex AIRBOSS:SetTACAN(channel, mode, morsecode)
AirbossAbe:SetTACAN(72, "X", "ABE")

-- Set ICLS channel. Default 1. 
-- Set Morse code identifier. Three letters, e.g. "STN". Default "STN".
AirbossAbe:SetICLS(1, "IAB")

-- Set beacon (TACAN/ICLS) time refresh interval in case the beacons die. Time interval in seconds. Default 1200 sec = 20 min.
AirbossAbe:SetBeaconRefresh(1200)

-- Airboss is a rather nice guy and not strictly following the rules. For example, he does allow you into the landing pattern if you are not coming from the Marshal stack.
AirbossAbe:SetAirbossNiceGuy(true)

-- Set carrier radio frequency and modulation. Default frequency is 305 MHz AM.
AirbossAbe:SetMarshalRadio(127.5, "AM")


-- Start airboss class.
AirbossAbe:Start()


--- Function called when recovery tanker is started.
function tanker:OnAfterStart(From,Event,To)

  -- Set recovery tanker.
  AirbossAbe:SetRecoveryTanker(tanker)  


  -- Use tanker as radio relay unit for LSO transmissions.
  AirbossAbe:SetRadioRelayLSO(self:GetUnitName())
  
end

--- Function called when AWACS is started.
function awacs:OnAfterStart(From,Event,To)
  -- Set AWACS.
  AirbossAbe:SetRecoveryTanker(tanker)  
end


--- Function called when rescue helo is started.
function rescuehelo:OnAfterStart(From,Event,To)
  -- Use rescue helo as radio relay for Marshal.
  AirbossAbe:SetRadioRelayMarshal(self:GetUnitName())
end

--- Function called when a player gets graded by the LSO.
function AirbossAbe:OnAfterLSOGrade(From, Event, To, playerData, grade)
  local PlayerData=playerData --Ops.Airboss#AIRBOSS.PlayerData
  local Grade=grade --Ops.Airboss#AIRBOSS.LSOgrade

  ----------------------------------------
  --- Interface your Discord bot here! ---
  ----------------------------------------
  
  local score=tonumber(Grade.points)
  local name=tostring(PlayerData.name)
  
  -- Report LSO grade to dcs.log file.
  env.info(string.format("Player %s scored %.1f", name, score))
end
